@@ -58,10 +58,10 @@ public:
 	qlonglong size;
 	qlonglong sent;
 	QString desc;
-	QString preview;
 	bool rangeSupported;
 	qlonglong rangeOffset, rangeLength, length;
 	QString streamType;
+	FTThumbnail thumbnail;
 	bool needStream;
 	QString id, iq_id;
 	BSConnection *c;
@@ -130,20 +130,20 @@ void FileTransfer::setProxy(const Jid &proxy)
 	d->proxy = proxy;
 }
 
-void FileTransfer::sendFile(const Jid &to, const QString &fname, qlonglong size, const QString &desc, const QString& preview)
+void FileTransfer::sendFile(const Jid &to, const QString &fname, qlonglong size,
+							const QString &desc, const FTThumbnail &thumb)
 {
 	d->state = Requesting;
 	d->peer = to;
 	d->fname = fname;
 	d->size = size;
 	d->desc = desc;
-	d->preview = preview;
 	d->sender = true;
 	d->id = d->m->link(this);
 
 	d->ft = new JT_FT(d->m->client()->rootTask());
 	connect(d->ft, SIGNAL(finished()), SLOT(ft_finished()));
-	d->ft->request(to, d->id, fname, size, desc, d->m->streamPriority(), preview);
+	d->ft->request(to, d->id, fname, size, desc, d->m->streamPriority(), thumb);
 	d->ft->go(true);
 }
 
@@ -176,6 +176,11 @@ void FileTransfer::writeFileData(const QByteArray &a)
 	d->c->write(block);
 }
 
+const FTThumbnail &FileTransfer::thumbnail() const
+{
+	return d->thumbnail;
+}
+
 Jid FileTransfer::peer() const
 {
 	return d->peer;
@@ -196,12 +201,6 @@ QString FileTransfer::description() const
 	return d->desc;
 }
 
-
-QString XMPP::FileTransfer::preview() const
-{
-	return d->preview;
-}
-
 bool FileTransfer::rangeSupported() const
 {
 	return d->rangeSupported;
@@ -311,8 +310,10 @@ void FileTransfer::stream_connected()
 
 void FileTransfer::stream_connectionClosed()
 {
+	bool err = (d->sent != d->length);
 	reset();
-	emit error(ErrStream);
+	if (err)
+		emit error(ErrStream);
 }
 
 void FileTransfer::stream_readyRead()
@@ -322,8 +323,8 @@ void FileTransfer::stream_readyRead()
 	if((qlonglong)a.size() > need)
 		a.resize((uint)need);
 	d->sent += a.size();
-	if(d->sent == d->length)
-		reset();
+//	if(d->sent == d->length) // we close it in stream_connectionClosed. at least for ibb
+//		reset();             // in other words we wait for another party to close the connection
 	readyRead(a);
 }
 
@@ -355,9 +356,9 @@ void FileTransfer::man_waitForAccept(const FTRequest &req, const QString &stream
 	d->fname = req.fname;
 	d->size = req.size;
 	d->desc = req.desc;
-	d->preview = req.preview;
 	d->rangeSupported = req.rangeSupported;
 	d->streamType = streamType;
+	d->thumbnail = req.thumbnail;
 }
 
 void FileTransfer::doAccept()
@@ -394,7 +395,7 @@ FileTransferManager::FileTransferManager(Client *client)
 	}
 
 	d->pft = new JT_PushFT(d->client->rootTask());
-	connect(d->pft, SIGNAL(incoming(const FTRequest &)), SLOT(pft_incoming(const FTRequest &)));
+	connect(d->pft, SIGNAL(incoming(FTRequest)), SLOT(pft_incoming(FTRequest)));
 }
 
 FileTransferManager::~FileTransferManager()
@@ -431,7 +432,7 @@ FileTransfer *FileTransferManager::takeIncoming()
 
 bool FileTransferManager::isActive(const FileTransfer *ft) const
 {
-	return d->list.contains(const_cast<FileTransfer*>(ft)) > 0;
+	return d->list.contains(const_cast<FileTransfer*>(ft));
 }
 
 void FileTransferManager::setDisabled(const QString &ns, bool state)
@@ -559,8 +560,8 @@ JT_FT::~JT_FT()
 }
 
 void JT_FT::request(const Jid &to, const QString &_id, const QString &fname,
-					qlonglong size, const QString &desc, const QStringList &streamTypes,
-					const QString& preview)
+					qlonglong size, const QString &desc,
+					const QStringList &streamTypes, const FTThumbnail &thumb)
 {
 	QDomElement iq;
 	d->to = to;
@@ -579,14 +580,22 @@ void JT_FT::request(const Jid &to, const QString &_id, const QString &fname,
 		de.appendChild(doc()->createTextNode(desc));
 		file.appendChild(de);
 	}
-	if(!preview.isEmpty()) {
-		QDomElement pr = doc()->createElement("preview");
-		pr.setAttribute("xmlns", "http://kopete.kde.org/protocol/file-preview");
-		pr.appendChild(doc()->createTextNode(preview));
-		file.appendChild(pr);
-	}
 	QDomElement range = doc()->createElement("range");
 	file.appendChild(range);
+
+	if (!thumb.data.isEmpty()) {
+		BoBData data = client()->bobManager()->append(thumb.data, thumb.mimeType);
+		QDomElement thel = doc()->createElement("thumbnail");
+		thel.setAttribute("xmlns", "urn:xmpp:thumbs:0");
+		thel.setAttribute("cid", data.cid());
+		thel.setAttribute("mime-type", thumb.mimeType);
+		if (thumb.width && thumb.height) {
+			thel.setAttribute("width", thumb.width);
+			thel.setAttribute("height", thumb.height);
+		}
+		file.appendChild(thel);
+	}
+
 	si.appendChild(file);
 
 	QDomElement feature = doc()->createElement("feature");
@@ -818,11 +827,6 @@ bool JT_PushFT::take(const QDomElement &e)
 	QDomElement de = file.elementsByTagName("desc").item(0).toElement();
 	if(!de.isNull())
 		desc = de.text();
-	
-	QString preview;
-	QDomElement pr = file.elementsByTagName("preview").item(0).toElement();
-	if(!pr.isNull())
-		preview= pr.text();
 
 	bool rangeSupported = false;
 	QDomElement range = file.elementsByTagName("range").item(0).toElement();
@@ -847,6 +851,15 @@ bool JT_PushFT::take(const QDomElement &e)
 		}
 	}
 
+	FTThumbnail thumb;
+	QDomElement thel = file.elementsByTagName("thumbnail").item(0).toElement();
+	if(!thel.isNull() && thel.attribute("xmlns") == QLatin1String("urn:xmpp:thumbs:0")) {
+		thumb.data = thel.attribute("cid").toUtf8();
+		thumb.mimeType = thel.attribute("mime-type");
+		thumb.width = thel.attribute("width").toUInt();
+		thumb.height = thel.attribute("height").toUInt();
+	}
+
 	FTRequest r;
 	r.from = from;
 	r.iq_id = e.attribute("id");
@@ -854,9 +867,9 @@ bool JT_PushFT::take(const QDomElement &e)
 	r.fname = fname;
 	r.size = size;
 	r.desc = desc;
-	r.preview = preview;
 	r.rangeSupported = rangeSupported;
 	r.streamTypes = streamTypes;
+	r.thumbnail = thumb;
 
 	emit incoming(r);
 	return true;
